@@ -43,16 +43,14 @@ def test_plot_tradeoff():
 
 
 def test_fit_phenotype():
-    large = q2.Artifact.load(
-        path.join(this_dir, "data", "large.qza"))
+    large = q2.Artifact.load(path.join(this_dir, "data", "growth.qza"))
     r = large.view(GrowthResults)
-    mcol = q2.Metadata.load(
-        path.join(this_dir, "data", "metadata.tsv")
-    ).get_column("status")
+    mcol = q2.Metadata.load(path.join(this_dir, "data", "metadata.tsv")).get_column(
+        "status"
+    )
     with TemporaryDirectory(prefix="q2-micom-") as d:
         q2m.fit_phenotype(str(d), r, mcol, min_coef=0.001)
         assert q2m.tests.check_viz(str(d))
     with TemporaryDirectory(prefix="q2-micom-") as d:
-        q2m.fit_phenotype(str(d), r, mcol, flux_type="import",
-                          min_coef=0.0)
+        q2m.fit_phenotype(str(d), r, mcol, flux_type="import", min_coef=0.0)
         assert q2m.tests.check_viz(str(d))
